@@ -79,4 +79,4 @@ ResamplingCustom = R6Class("ResamplingCustom", inherit = Resampling,
 )
 
 #' @include mlr_resamplings.R
-mlr_resamplings$add("custom", ResamplingCustom)
+mlr_resamplings$add("custom", function() ResamplingCustom$new())
