@@ -134,4 +134,4 @@ ResamplingRepeatedCV = R6Class("ResamplingRepeatedCV", inherit = Resampling,
 )
 
 #' @include mlr_resamplings.R
-mlr_resamplings$add("repeated_cv", ResamplingRepeatedCV)
+mlr_resamplings$add("repeated_cv", function() ResamplingRepeatedCV$new())
