@@ -105,7 +105,6 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
   }
   assert_task_learner(design$task[[1]], design$learner[[1]])
 
-  # clone inputs
   setDT(design)
   task = learner = resampling = NULL
   if ("task" %in% clone) {
@@ -159,7 +158,7 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
       if (!is.null(learner$hotstart_stack)) {
         # search for hotstart learner
         learner = learner$clone()
-        task_hashes = task_hashes(task, resampling)
+        task_hashes = resampling_task_hashes(task, resampling, learner)
         start_learner = get_private(learner$hotstart_stack)$.start_learner(learner, task_hashes[iteration])
       }
       if (is.null(learner$hotstart_stack) || is.null(start_learner)) {
